package de.intevation.flys.importer;

import java.sql.SQLException;
import java.util.ArrayList;
import java.util.List;

import org.apache.log4j.Logger;

import org.hibernate.Session;
import org.hibernate.Query;
import org.hibernate.exception.ConstraintViolationException;

import de.intevation.flys.model.FlowVelocityMeasurement;
import de.intevation.flys.model.River;


public class ImportFlowVelocityMeasurement {

    private static final Logger log =
        Logger.getLogger(ImportFlowVelocityMeasurement.class);


    private String description;

    private List<ImportFlowVelocityMeasurementValue> values;

    private FlowVelocityMeasurement peer;


    public ImportFlowVelocityMeasurement() {
        this(null);
    }


    public ImportFlowVelocityMeasurement(String description) {
        this.description = description;
        this.values      = new ArrayList<ImportFlowVelocityMeasurementValue>();
    }


    public void setDescription(String description) {
        this.description = description;
    }


    public void addValue(ImportFlowVelocityMeasurementValue value) {
        this.values.add(value);
    }


    public void storeDependencies(River river)
    throws SQLException, ConstraintViolationException
    {
        log.debug("store dependencies");

        FlowVelocityMeasurement peer = getPeer(river);

        for (ImportFlowVelocityMeasurementValue value: values) {
            value.storeDependencies(peer);
        }
    }


    public FlowVelocityMeasurement getPeer(River river) {
        if (peer == null) {
            Session session = ImporterSession.getInstance().getDatabaseSession();

            Query query = session.createQuery(
                "from FlowVelocityMeasurement where " +
                "   river=:river and " +
                "   description=:description"
            );

            query.setParameter("river", river);
            query.setParameter("description", description);

            List<FlowVelocityMeasurement> measurement = query.list();

            if (measurement.isEmpty()) {
                peer = new FlowVelocityMeasurement(river, description);

                session.save(peer);
            }
            else {
                peer = measurement.get(0);
            }
        }

        return peer;
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
